@@ -33,6 +33,7 @@ from agentkit.toolkit.config import (
     CloudStrategyConfig,
     merge_runtime_envs,
 )
+from agentkit.toolkit.config.region_resolver import RegionConfigResolver
 from agentkit.toolkit.builders.ve_pipeline import VeCPCRBuilder, VeCPCRBuilderConfig
 from agentkit.toolkit.runners.ve_agentkit import (
     VeAgentkitRuntimeRunner,
@@ -286,16 +287,19 @@ class CloudStrategy(Strategy):
         if self.config_manager:
             docker_build_config = self.config_manager.get_docker_build_config()
 
+        resolver = RegionConfigResolver.from_strategy_config(strategy_config)
+
         return VeCPCRBuilderConfig(
             common_config=common_config,
+            cp_region=resolver.resolve("cp"),
             tos_bucket=strategy_config.tos_bucket,
-            tos_region=strategy_config.tos_region,
+            tos_region=resolver.resolve("tos"),
             tos_prefix=strategy_config.tos_prefix,
             cr_instance_name=strategy_config.cr_instance_name,
             cr_namespace_name=strategy_config.cr_namespace_name,
             cr_repo_name=strategy_config.cr_repo_name,
             cr_auto_create_instance_type=strategy_config.cr_auto_create_instance_type,
-            cr_region=strategy_config.cr_region,
+            cr_region=resolver.resolve("cr"),
             cp_workspace_name=strategy_config.cp_workspace_name,
             cp_pipeline_name=cp_pipeline_name_override
             or strategy_config.cp_pipeline_name,
@@ -312,9 +316,18 @@ class CloudStrategy(Strategy):
         Convert VeAgentkitConfig to VeAgentkitRunnerConfig.
 
         Centralizes configuration mapping to keep orchestration logic clear.
-        Merges environment variables from common and strategy configs.
+        Merges environment variables from common and strategy configs with veADK compatibility.
         """
-        merged_envs = merge_runtime_envs(common_config, strategy_config.to_dict())
+        # Get project directory from config manager if available
+        project_dir = None
+        if self.config_manager:
+            project_dir = self.config_manager.get_project_dir()
+
+        merged_envs = merge_runtime_envs(
+            common_config, strategy_config.to_dict(), project_dir
+        )
+
+        resolver = RegionConfigResolver.from_strategy_config(strategy_config)
 
         return VeAgentkitRunnerConfig(
             common_config=common_config,
@@ -325,5 +338,9 @@ class CloudStrategy(Strategy):
             runtime_apikey_name=strategy_config.runtime_apikey_name,
             runtime_endpoint=strategy_config.runtime_endpoint,
             runtime_envs=merged_envs,
+            runtime_auth_type=strategy_config.runtime_auth_type,
+            runtime_jwt_discovery_url=strategy_config.runtime_jwt_discovery_url,
+            runtime_jwt_allowed_clients=strategy_config.runtime_jwt_allowed_clients,
             image_url=strategy_config.cr_image_full_url,
+            region=resolver.resolve("agentkit"),
         )
